@@ -1,28 +1,52 @@
-##//////////////////////////////////////////////
-##//pHM Transformation.R with interpolation 
-##/////////////////////////////////////////////
-##======================================
-#author: Sebastian Kreutzer
-#organisation: JLU Giessen
-#vers.: 0.2
-#date: 15/12/2012
-##======================================
+##//////////////////////////////////////////////////////////////////////////////
+##//CW2pHMi.R 
+##//////////////////////////////////////////////////////////////////////////////
+##==============================================================================
+##author: Sebastian Kreutzer
+##organisation: JLU Giessen
+##version: 0.2
+##date: 2013-03-27
+##==============================================================================
 ##Based on the paper of Bos and Wallinga, 2012 (Radiation Measurements) and the 
 ##personal comments and suggestions of Adrie Bos via e-mail
 
-
 CW2pHMi<-function(values, delta){
 
-  # (0) Integrity checks ------------------------------------------------------------------------
-  if(is.data.frame(values)==FALSE){stop("[CW2pHMi] >> Input object is not of type data.frame!")}
-
-  # (1) Transform values ------------------------------------------------------------------------                  								
+  ##(1) data.frame or RLum.Data.Curve object?
+  if(is(values, "data.frame") == FALSE & is(values, "RLum.Data.Curve") == FALSE){
+    
+    stop("[CW2pHMi] Error: 'values' object has to be of type 'data.frame' or 'RLum.Data.Curve'!")
+    
+  }
+  
+  ##(2) if the input object is an 'RLum.Data.Curve' object check for allowed curves
+  if(is(values, "RLum.Data.Curve") == TRUE){
+    
+    if(values@recordType != "OSL" & values@recordType != "IRSL"){
+      
+      stop(paste("[CW2pHMi] Error: curve type ",values@recordType, "  is not allowed for the transformation!",
+                 sep=""))
+      
+    }else{
+      
+      temp.values <- as(values, "data.frame")
+      
+    }
+    
+  }else{
+    
+    temp.values <- values
+    
+  }
+ 
+  
+  # (1) Transform values ------------------------------------------------------                  								
     
     ##log transformation of the CW-OSL count values
-    CW_OSL.log<-log(values[,2])
+    CW_OSL.log<-log(temp.values[,2])
   
     ##time transformation t >> t'
-    t<-values[,1]
+    t<-temp.values[,1]
 
     ##set delta
     ##if no values for delta is set selected a delta value for a maximum of 
@@ -46,7 +70,7 @@ CW2pHMi<-function(values, delta){
     
    }  
 
-  # (2) Interpolation ---------------------------------------------------------------------------
+  # (2) Interpolation ---------------------------------------------------------
 
    ##interpolate values, values beyond the range return NA values
    CW_OSL.interpolated<-approx(t,CW_OSL.log, xout=t.transformed, rule=1 )
@@ -73,7 +97,7 @@ CW2pHMi<-function(values, delta){
           temp[invalid_values.id,2]<-invalid_values.interpolated
       }
     
-  # (3) Extrapolate first values of the curve ---------------------------------------------------
+  # (3) Extrapolate first values of the curve ---------------------------------
     
    ##(a) - find index of first rows which contain NA values (needed for extrapolation)
    temp.sel.id<-min(which(is.na(temp[,2])==FALSE))
@@ -94,7 +118,7 @@ CW2pHMi<-function(values, delta){
    ##print a warning message for more than two extrapolation points
    if(length(y.i)>2){warning("t' is beyond the time resolution and more than two data points have been extrapolated!")}
   
-  # (4) Convert, transform and combine values --------------------------------------------------- 
+  # (4) Convert, transform and combine values --------------------------------- 
 
   ##unlog CW-OSL count values, i.e. log(CW) >> CW
   CW_OSL<-exp(temp$y)
@@ -102,7 +126,7 @@ CW2pHMi<-function(values, delta){
   ##set values for c and P
   
     ##P is the stimulation period
-    P<-max(values[,1])
+    P<-max(temp.values[,1])
 
     ##c is a dimensionless constant
     c<-(1+(delta*P))/(delta*P)
@@ -111,11 +135,31 @@ CW2pHMi<-function(values, delta){
   pHM<-((delta*t)/(1+(delta*t)))*c*CW_OSL
 
   ##combine all values and exclude NA values
-  values<-data.frame(x=t,y.t=pHM,x.t=t.transformed,method=temp.method)
-  values<-na.exclude(values)
+  temp.values<-data.frame(x=t,y.t=pHM,x.t=t.transformed,method=temp.method)
+  temp.values<-na.exclude(temp.values)
 
-  # (5) Return values ---------------------------------------------------------------------------  
+  # (5) Return values ---------------------------------------------------------  
+  
+  ##returns the same data type as the input
+  if(is(values, "data.frame") == TRUE){
+    
+    values <- temp.values
+    return(values)
+    
+  }else{
+    
+    
+    ##add old info elements to new info elements
+    temp.info <- c(values@info, 
+                   CW2pHMi.x.t = list(temp.values$x.t),
+                   CW2pHMi.method = list(temp.values$method)) 
+    
+    newRLumDataCurves.CW2pHMi <- set_RLum.Data.Curve(recordType = values@recordType,
+                                                     data = as.matrix(temp.values[,1:2]),
+                                                     info = temp.info)
+    return(newRLumDataCurves.CW2pHMi)                                                    
+    
+  }
   
-  return(values)
 }
 ##EOF
